'use strict'

var webpack = require('webpack')
var UglifyJsPlugin = require('uglifyjs-webpack-plugin')
var WebpackAsyncPlugin = require('webpack-async-await')

module.exports = {
  entry: __dirname + '/tap.js',
  output: {
    path: __dirname + '/dist',
    filename: 'tap.min.js'
  },
  module: {
    rules: [
      {
        test: /\.json$/,
        loader: 'json-loader'
      }
    ]
  },
  node: {
    console: true,
    fs: 'empty',
    net: 'empty',
    tls: 'empty'
  },
  plugins: [
    new UglifyJsPlugin({
      uglifyOptions: {
        compress: {
          warnings: false, // Suppress uglification warnings
          pure_getters: true,
          unsafe: true,
          unsafe_comps: true
        },
        sourceMap: true,
        mangle: true,
        output: {
          comments: false
        },
        exclude: [/\.min\.js$/gi] // skip pre-minified libs
      }
    }),
    new webpack.IgnorePlugin(/^\.\/locale$/, [/moment$/]),
    new WebpackAsyncPlugin({
      asyncawait: true,
      sourceMap: true,
      warnings: true
    }),
    new webpack.optimize.AggressiveMergingPlugin(),
    new webpack.DefinePlugin({
      'process.env.NODE_ENV': '"production"'
    })
  ]
}
